[**快速开始**](./getting-started.md) > **如何使用** > **命令行** _(当前页面)_

---

### 通过命令行使用 PDFMathTranslate

#### 基本用法

安装后，请输入此命令来翻译您的 PDF。

```bash
pdf2zh_next document.pdf
```

> [!NOTE]
> 
> 如果您的路径名包含空格，请将其括在引号中。
> 
> ```bash
> pdf2zh_next "path with spaces/document.pdf"
> ```

执行翻译后，文件将生成在 **当前工作目录** 中。

> [!TIP]
> **Where is my "Current Working Directory" ?**
> 在终端中输入命令之前，您可能会看到路径名显示在您的终端中：
> 
> ```powershell
> PS C:\Users\XXX>
> ```
> 
> 此目录是 "*当前工作目录*."
> 
> 如果路径名不存在，请在终端中运行此命令：
> 
> ```bash
> pwd
> ```
> 
> 执行此命令后，将输出路径名。此路径名是 "**当前工作目录**"。翻译后的文件将出现在这里。

---

#### 高级用法

有关其他命令行参数的详细说明，请参阅 [高级用法](./../advanced/ADVANCED_usage.md)。

<div align="right">
<h6><small>此页面部分内容由 GPT 翻译，可能包含错误。</small></h6>